@@ -8,7 +8,8 @@ import numpy as np
 from pyfits.column import (ASCIITNULL, FITS2NUMPY, Column, ColDefs, _FormatX,
                            _FormatP, _VLF, _get_index, _wrapx, _unwrapx,
                             _convert_ascii_format)
-from pyfits.util import _array_from_file, decode_ascii, lazyproperty
+from pyfits.util import (_array_from_file, decode_ascii, encode_ascii,
+                         lazyproperty)
 
 
 class FITS_record(object):
@@ -183,6 +184,53 @@ class FITS_rec(np.recarray):
         self.formats = None
         return self
 
+    def __setstate__(self, state):
+        meta = state[-1]
+        column_state = state[-2]
+        state = state[:-2]
+
+        super(FITS_rec, self).__setstate__(state)
+
+        for attr, value in zip(meta, column_state):
+            setattr(self, attr, value)
+
+    def __reduce__(self):
+        """
+        Return a 3-tuple for pickling a FITS_rec. Use the super-class
+        functionality but then add in a tuple of FITS_rec-specific
+        values that get used in __setstate__.
+        """
+
+        reconst_func, reconst_func_args, state = \
+            super(FITS_rec, self).__reduce__()
+
+        # Define FITS_rec-specific attrs that get added to state
+        column_state = []
+        meta = []
+
+        for attrs in ['_convert', '_heapoffset', '_heapsize', '_nfields',
+                      '_gap', '_uint', 'names', 'formats', 'parnames',
+                      '_coldefs', '_file', '_buffer']:
+
+            try:
+                # _coldefs can be Delayed, and file objects cannot be
+                # picked, it needs to be deepcopied first
+                if attrs == '_coldefs':
+                    column_state.append(self._coldefs.__deepcopy__(None))
+                elif attrs == '_file':
+                    # We don't actually need to preserve this attribute and
+                    # trying to pickle it will fail
+                    column_state.append(None)
+                else:
+                    column_state.append(getattr(self, attrs))
+                meta.append(attrs)
+            except AttributeError:
+                pass
+
+        state = state + (column_state, meta)
+
+        return reconst_func, reconst_func_args, state
+
     def __array_finalize__(self, obj):
         if obj is None:
             return
@@ -407,10 +455,12 @@ class FITS_rec(np.recarray):
 
                 # if the string = TNULL, return ASCIITNULL
                 nullval = self._coldefs.nulls[indx].strip().encode('ascii')
-                dummy = field.replace('D'.encode('ascii'),
-                                      'E'.encode('ascii'))
-                dummy = np.where(dummy.strip() == nullval, str(ASCIITNULL),
-                                 dummy)
+                dummy = field.replace(encode_ascii('D'),
+                                      encode_ascii('E'))
+                width = self._coldefs.spans[indx]
+                null_fill = encode_ascii(str(ASCIITNULL).rjust(width))
+                dummy = np.where(dummy.strip() == nullval, null_fill, dummy)
+
                 try:
                     dummy = np.array(dummy, dtype=_type)
                 except ValueError, e:
