@@ -5,7 +5,6 @@ import functools
 import itertools
 import mmap
 import os
-import platform
 import signal
 import sys
 import tempfile
@@ -457,6 +456,11 @@ def fileobj_closed(f):
     file-like object.
     """
 
+    # Workaround for inconsistent handling of file path strings in parts of
+    # PyFITS 3.1.x
+    if isinstance(f, basestring):
+        return True
+
     if hasattr(f, 'closed'):
         return f.closed
     elif hasattr(f, 'fileobj') and hasattr(f.fileobj, 'closed'):
@@ -464,7 +468,7 @@ def fileobj_closed(f):
     elif hasattr(f, 'fp') and hasattr(f.fp.closed):
         return f.fp.closed
     else:
-        return True
+        return False
 
 
 def fileobj_mode(f):
@@ -592,8 +596,8 @@ def _array_to_file(arr, outfile):
     # implemented there yet: https://github.com/astropy/astropy/issues/839
     osx_write_limit = (2 ** 32) - 1
 
-    if (sys.platform == 'darwin' and platform.architecture()[0] == '64bit' and
-            arr.nbytes >= osx_write_limit + 1 and arr.nbytes % 4096 == 0):
+    if (sys.platform == 'darwin' and arr.nbytes >= osx_write_limit + 1 and
+            arr.nbytes % 4096 == 0):
         idx = 0
         # chunksize is a count of elements in the array, not bytes
         chunksize = osx_write_limit // arr.itemsize
@@ -833,3 +837,27 @@ if sys.version_info[:2] < (2, 6):
 
             return cls_ns[property_name]
     __builtin__.property = property
+
+
+    # Provide an implementation of izip_longest
+    class ZipExhausted(Exception):
+        pass
+
+    def izip_longest(*args, **kwds):
+        # izip_longest('ABCD', 'xy', fillvalue='-') --> Ax By C- D-
+        fillvalue = kwds.get('fillvalue')
+        counter = [len(args) - 1]
+        def sentinel():
+            if not counter[0]:
+                raise ZipExhausted
+            counter[0] -= 1
+            yield fillvalue
+        fillers = itertools.repeat(fillvalue)
+        iterators = [itertools.chain(it, sentinel(), fillers) for it in args]
+        try:
+            while iterators:
+                yield tuple(map(lambda it: it.next(), iterators))
+        except ZipExhausted:
+            pass
+
+    itertools.izip_longest = izip_longest
